/*
 * Copyright (C) 2009 Igalia S.L.
 *
 * Contact: Iago Toral Quiroga <itoral@igalia.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public License
 * as published by the Free Software Foundation; version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA
 *
 */

#ifndef _MAFW_SIMPLE_RENDERER_H_
#define _MAFW_SIMPLE_RENDERER_H_

#include <glib-object.h>
#include <libmafw/mafw.h>
#include <libmafw/mafw-renderer.h>
#include <libmafw/mafw-registry.h>
#include <gst/gst.h>
#include <gst/pbutils/pbutils.h>

/* GObject macros */

#define MAFW_TYPE_SIMPLE_RENDERER (mafw_simple_renderer_get_type())
#define MAFW_SIMPLE_RENDERER(obj)                                          \
        (G_TYPE_CHECK_INSTANCE_CAST((obj),				\
				    MAFW_TYPE_SIMPLE_RENDERER,		\
				    MafwSimpleRenderer))
#define MAFW_IS_SIMPLE_RENDERER(obj)                                       \
        (G_TYPE_CHECK_INSTANCE_TYPE((obj), MAFW_TYPE_SIMPLE_RENDERER))
#define MAFW_SIMPLE_RENDERER_CLASS(klass)                                  \
	(G_TYPE_CHECK_CLASS_CAST((klass), \
				 MAFW_TYPE_SIMPLE_RENDERER, \
				 MafwSimpleRenderer))
#define MAFW_SIMPLE_RENDERER_GET_CLASS(obj)                                \
	(G_TYPE_INSTANCE_GET_CLASS((obj), \
				   MAFW_TYPE_SIMPLE_RENDERER,	\
				   MafwSimpleRendererClass))
#define MAFW_IS_SIMPLE_RENDERER_CLASS(klass)                               \
	(G_TYPE_CHECK_CLASS_TYPE((klass), MAFW_TYPE_SIMPLE_RENDERER))

#define MAFW_SIMPLE_RENDERER_ERROR (mafw_simple_renderer_error_quark ())

/* Plugin name */
#define MAFW_SIMPLE_RENDERER_PLUGIN_NAME "MAFW-Simple-Renderer-Plugin"
/* Renderer name */
#define MAFW_SIMPLE_RENDERER_NAME "MAFW Simple Renderer"
/* Renderer UUID */
#define MAFW_SIMPLE_RENDERER_UUID "mafwsimpleren"

/* GObject definition */
typedef struct _MafwSimpleRenderer MafwSimpleRenderer;
typedef struct _MafwSimpleRendererClass MafwSimpleRendererClass;
typedef struct _MafwSimpleRendererPrivate MafwSimpleRendererPrivate;

struct _MafwSimpleRenderer {
        MafwRenderer parent;

        /* private */
        MafwSimpleRendererPrivate *priv;
};

struct _MafwSimpleRendererClass {
        MafwRendererClass parent_class;
};

GType mafw_simple_renderer_get_type (void);
gboolean mafw_simple_renderer_plugin_initialize (MafwRegistry * registry, GError **error);
void mafw_simple_renderer_plugin_deinitialize (GError **error) ;

G_END_DECLS

#endif
