#include <glib.h>
#include <string.h>
#include <time.h>
#include <stdlib.h>

#include <libmafw-shared/mafw-shared.h>
#include <libmafw-shared/mafw-playlist-manager.h>

#include "../src/mafw-simple-renderer.h"

static MafwRenderer *renderer = NULL;
static GMainLoop *loop = NULL;

static void
init_test (void)
{
        GError *error = NULL;
        MafwRegistry *registry = NULL;
        GList *renderers;
	
        g_type_init ();
	
        registry = MAFW_REGISTRY (mafw_registry_get_instance ());

        mafw_shared_init (registry, &error);
        if (error != NULL)
        {
                g_warning ("Ext. discovery failed: %s", error->message);
                g_error_free(error);
                error = NULL;
        }

        renderers = mafw_registry_get_renderers (registry);
        if (renderers == NULL) {
                mafw_simple_renderer_plugin_initialize (registry, &error);
                renderers = mafw_registry_get_renderers (registry);
        }
	
        if (renderers == NULL) {
                g_critical ("Failed to load plugin");
                if (error != NULL) {
                        g_critical ("%s", error->message);
                }
                g_assert_not_reached ();
        }

        renderer = MAFW_RENDERER (renderers->data);

        g_assert (renderer != NULL);
}

static MafwPlaylist *
create_playlist (int n, gchar **objectids, GError **error)
{
	MafwPlaylistManager *manager;
	MafwPlaylist *pls;
	gint i;
	
	/* Ask the playlist manager to create a playlist
	 named "test-playlist" */
        manager = mafw_playlist_manager_get ();
        pls =  MAFW_PLAYLIST (
		mafw_playlist_manager_create_playlist (manager,
						       "test-playlist",
						       error));	
	/* Failed to create playlist */
	if (pls == NULL)
		return pls;

	/* If the playlist existed, the manager returns
	   a reference to the old playlist, but we want a 
	   new one */
	mafw_playlist_clear (pls, NULL);

	/* And now, we add our objectids */
	i = 0;
	do {
		mafw_playlist_append_item (pls, objectids[i++], NULL);
	} while (i < n);

	return pls;
}

static void
playback_cb (MafwRenderer *renderer, gpointer user_data, const GError *error)
{
	if (error) {
		g_error ("Error while playing: %s", 
			 error ? error->message : "");
	}
}

static gboolean
do_assign_pls (MafwPlaylist *pls)
{
	GError *error = NULL;

	if (!mafw_renderer_assign_playlist (renderer, pls, &error)) {
		g_error ("Failed to assign playlist. %s",
			 error ? error->message : "");
	}
	
	mafw_renderer_play (renderer, playback_cb, NULL);

	return FALSE;
}

int
main (gint argc, gchar *argv[])
{
	GError *error = NULL;
	MafwPlaylist *pls = NULL;

        if (argc < 2) {
		g_print ("test  objectid1 [objectid2] ...\n");
		exit (1);
	}
	
        init_test ();

	/* Create a playlist from command line arguments */
	pls = create_playlist (argc - 1, &argv[1], &error);
	if (pls == NULL) {
		g_error ("Failed to create playlist: %s",
			 error ? error->message : "");
	}

	/* We have the playlist, so let's start the test*/
	g_timeout_add_seconds (1, (GSourceFunc) do_assign_pls, pls);

        loop = g_main_loop_new (NULL, FALSE);
        g_main_loop_run (loop);

        return 0;
}
